PyXMake Developer Guide: PyXMake.VTL Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Namespaces | Functions | Variables
PyXMake.VTL Namespace Reference

Module containing virtual testing & benchmark scripts. More...

## Namespaces
| abaqus
| api
| app
| bundle
| cxx
| doxygen
| ifort
| java
| py2x
| sphinx
| ssh_f2py
| ssh_ifort
| ssh_make
| stm_make
| Start build jobs on the Jenkins Test Server using PyXMake.

## Functions
def | GetSourceCode (key_opt=0)
def | GetBuildCommand (make_opt=0, _format="fixed", _arch=Utility.GetArchitecture())
def | GetIncludeDirectory (base_path, key_opt=0, make_opt=0, architecture="x64")
def | GetLinkDependency (key_opt=0, make_opt=0, architecture="x64")
def | GetEnvironment (env_opt=0)

## Variables
| Scratch = os.path.join(os.path.dirname(os.path.abspath(__file__)),"scratch")

## Detailed Description

Module containing virtual testing & benchmark scripts.

    Module containing virtual testing & benchmark scripts.

    @note: PyXMake module
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  18.03.2019

Notes/Changes
  - Added documentation // mg 18.03.2019
  - Renamed VTC with VTL // mg 04.04.2019

## Function Documentation

## ◆ GetBuildCommand()

def PyXMake.VTL.GetBuildCommand | ( |  | make_opt = `0`,
|  |  | _format = `"fixed"`,
|  |  | _arch = `Utility.GetArchitecture()`
| ) |  |

    Return the recommended command line during the build process for selected make operations.

    @param: make_opt: An integer value representing the make operation.
    @type: make_opt: integer

Definition at line 116 of file __init__.py.

## ◆ GetEnvironment()

def PyXMake.VTL.GetEnvironment | ( |  | env_opt = `0` | ) |

    Return predefined source environment to initiate a build process.

    @param: env_opt An integer value representing a predefined environment
    @type: env_opt: integer

Definition at line 339 of file __init__.py.

## ◆ GetIncludeDirectory()

def PyXMake.VTL.GetIncludeDirectory | ( |  | base_path,
|  |  | key_opt = `0`,
|  |  | make_opt = `0`,
|  |  | architecture = `"x64"`
| ) |  |

    Return all mandatory include directories for the requested make operation in dependence of key_opt.

    @param: key_opt, make_opt: [An integer value representing the source code file (e.g. MCODAC, BoxBeam, BEOS),
                                                      An integer value representing the make operation.]
    @type: key_opt, make_opt: integer

Definition at line 244 of file __init__.py.

## ◆ GetLinkDependency()

def PyXMake.VTL.GetLinkDependency | ( |  | key_opt = `0`,
|  |  | make_opt = `0`,
|  |  | architecture = `"x64"`
| ) |  |

    Return all mandatory external libraries for the requested make operation in dependence of key_opt.

    @param: key_opt, make_opt: [An integer value representing the source code file (e.g. MCODAC, BoxBeam, BEOS),
                                                      An integer value representing the make operation.]
    @type: key_opt, make_opt: integer

Definition at line 310 of file __init__.py.

## ◆ GetSourceCode()

def PyXMake.VTL.GetSourceCode | ( |  | key_opt = `0` | ) |

    Get a list of source codes files associated with the build of MCODAC, BoxBeam or BEOS.

    @param: key_opt: An integer value representing the source code files.
    @type: key_opt: integer

Definition at line 41 of file __init__.py.